InteractionNotification class
A notification that informs parent widgets that an interaction has started.
Used by GlassSheet to suppress its own scaling/glow when a child widget is being touched.
- Inheritance
-
- Object
- Notification
- InteractionNotification
Constructors
- InteractionNotification(PointerDownEvent event)
- Creates an InteractionNotification.
Properties
- event → PointerDownEvent
-
The pointer event that triggered this notification.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debugFillDescription(
List< String> description) → void -
Add additional information to the given description for use by toString.
inherited
-
dispatch(
BuildContext? target) → void -
Start bubbling this notification at the given build context.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited