GlassChartLegendEntry class

A single row in a GlassChart's legend.

Annotations

Constructors

GlassChartLegendEntry({required Color color, required String label})
Creates a legend entry.
const

Properties

color Color
Swatch color for this series.
final
hashCode int
The hash code for this object.
no setterinherited
label String
Series label.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited