falloff property
Gradient gamma. >1 keeps the blur strong across the strong edge then eases to sharp near the opposite edge.
Implementation
final double falloff;
Gradient gamma. >1 keeps the blur strong across the strong edge then eases to sharp near the opposite edge.
final double falloff;