icon property
The icon widget to display.
Typically an Icon or CupertinoIcons icon widget. The parent GlassButtonGroup wraps this in an IconTheme that sets size and color based on the current brightness.
Implementation
final Widget icon;
The icon widget to display.
Typically an Icon or CupertinoIcons icon widget. The parent GlassButtonGroup wraps this in an IconTheme that sets size and color based on the current brightness.
final Widget icon;