GlassThemeHelpers class
Helper functions for working with Glass Theme.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → GlassThemeData - Retrieves the theme data from the widget tree.
-
resolveAdaptiveRadius(
BuildContext context) → double - Resolves an adaptive border radius based on the device's physical geometry.
-
resolveQuality(
BuildContext context, {GlassQuality? widgetQuality, GlassQuality fallback = GlassQuality.standard}) → GlassQuality - Resolves the effective GlassQuality for a widget.
-
resolveSettings(
BuildContext context, {LiquidGlassSettings? explicit, LiquidGlassSettings fallback = const LiquidGlassSettings()}) → LiquidGlassSettings - Resolves LiquidGlassSettings for a widget using the full priority chain.