GlassTextField.search constructor
const
GlassTextField.search({
- Key? key,
- TextEditingController? controller,
- FocusNode? focusNode,
- String? placeholder,
- Widget? prefixIcon,
- Widget? suffixIcon,
- VoidCallback? onSuffixTap,
- bool enabled = true,
- bool readOnly = false,
- bool autofocus = false,
- ValueChanged<
String> ? onChanged, - ValueChanged<
String> ? onSubmitted, - List<
TextInputFormatter> ? inputFormatters, - TextStyle? textStyle,
- TextStyle? placeholderStyle,
- EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
- double iconSpacing = 8.0,
- double? height = 44.0,
- LiquidShape shape = const LiquidRoundedRectangle(borderRadius: 22),
- LiquidGlassSettings? settings,
- bool useOwnLayer = false,
- GlassQuality? quality,
- GlassInteractionBehavior interactionBehavior = GlassInteractionBehavior.full,
- double pressScale = 1.03,
- Color? glowColor,
- double glowRadius = 1.5,
- TapRegionCallback? onTapOutside,
Creates a glass text field styled specifically for search, matching the compact layout and visuals of GlassSearchBar.
Implementation
const GlassTextField.search({
super.key,
this.controller,
this.focusNode,
this.placeholder,
this.prefixIcon,
this.suffixIcon,
this.onSuffixTap,
this.enabled = true,
this.readOnly = false,
this.autofocus = false,
this.onChanged,
this.onSubmitted,
this.inputFormatters,
this.textStyle,
this.placeholderStyle,
this.padding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8),
this.iconSpacing = 8.0,
this.height = 44.0,
this.shape = const LiquidRoundedRectangle(borderRadius: 22),
this.settings,
this.useOwnLayer = false,
this.quality,
this.interactionBehavior = GlassInteractionBehavior.full,
this.pressScale = 1.03,
this.glowColor,
this.glowRadius = 1.5,
this.onTapOutside,
}) : obscureText = false,
keyboardType = TextInputType.text,
textInputAction = TextInputAction.search,
maxLines = 1,
minLines = 1,
maxLength = null,
onLineCountChanged = null,
iconAlignment = CrossAxisAlignment.center,
minHeight = null,
maxHeight = null,
bottom = null;