onTapOutside property
Called when the user taps outside the text field.
Defaults to unfocusing the field, which dismisses the keyboard.
Implementation
final TapRegionCallback? onTapOutside;
Called when the user taps outside the text field.
Defaults to unfocusing the field, which dismisses the keyboard.
final TapRegionCallback? onTapOutside;